mod builder;
mod entries;
mod file;

pub use builder::Builder;

use crate::archive::Handle;
use crate::ReadFilter;
use entries::Entries;
use libarchive3_sys::ffi;
use std::path::Path;

// Represents a read view of an archive
pub trait Archive: Handle + Sized {
    fn new(handle: *mut ffi::Struct_archive) -> Self;

    fn open<P: AsRef<Path>>(builder: Builder, path: P) -> crate::Result<Self>;

    fn entries<'a>(&'a mut self) -> Entries<'a, Self> {
        Entries::new(self)
    }

    fn filter(&mut self, index: i32) -> ReadFilter {
        let res = unsafe { ffi::archive_filter_code(self.handle_mut(), index) };

        match res {
            0 => ReadFilter::None,
            _ => panic!("Unknown filter type"),
        }
    }
}
